
# Vo všetkých vstupoch platí $1\leq n\leq 1000$, $1\leq k\leq n$ a $1\leq h_i\leq 10^9$ pre všetky $i$.
# V rámci každej sady vstupov majú všetky vstupy tú istú hodnotu $\ell$.
# hodnota $\ell$ & 0 & 1000 & 2000 & 3000 & 1500 \\
# maximálne $n$ & 1000 & 20 & 100 & 1000 & 1000 

from random import randint, seed, sample, choice, shuffle
from string import ascii_lowercase as abc
seed(47)

ONLYL = [ None, 0, 1000, 2000, 3000, 1500 ]
MAXN = [ None, 1000, 20, 100, 1000, 1000 ]

def save(fname, K, L, vysky):
    f = open(fname, 'w')
    print( len(vysky), K, L, file=f )
    print( *vysky, file=f )
    f.close()

def gen_few(N, C):
    options = set()
    while len(options) < C: options.add( randint(1,10**9) )
    options = list(options)
    return [ choice(options) for n in range(N) ]

def gen_solvable(N, K):
    A = [ randint(1,10**9) for n in range(N) ]
    A.sort()
    king = A[K-1]
    while True:
        shuffle(A)
        if A[K-1] == king: break
    return (A, K)

def gen_reverse(N, K, swaps = 0):
    A = [ randint(1,10**9) for n in range(N) ]
    A.sort()
    king = A[K-1]
    rest = A[:K-1] + A[K:]
    rest = list(reversed(rest))
    for i in range(swaps):
        x = randint(0, len(rest)-1)
        y = randint(0, len(rest)-1)
        rest[x], rest[y] = rest[y], rest[x]
    return rest[:K-1] + [king] + rest[K-1:]

save('00a.in', 3, 100, [160,165,175,170,180] )
save('00b.in', 3, 100, [185,180,175,170,165] )
save('00c.in', 3, 0,   [175,170,175,180,175] )
save('00d.in', 3, 100, [175,170,175,180,175] )

TESTS = [ [] for _ in range(6) ]

TESTS[1].append( (1, 0, [47]) )
TESTS[1].append( (1, 0, [47, 42]) )
TESTS[1].append( (1, 0, [42, 47]) )
TESTS[1].append( (2, 0, [47, 42]) )
TESTS[1].append( (2, 0, [42, 47]) )
TESTS[1].append( (2, 0, [23, 42, 47]) )
TESTS[1].append( (2, 0, [47, 42, 23]) )
TESTS[1].append( (1, 0, [42, 42, 47]) )
TESTS[1].append( (1, 0, [47, 42, 42]) )
TESTS[1].append( (2, 0, [42, 42, 47]) )
TESTS[1].append( (2, 0, [47, 42, 42]) )
TESTS[1].append( (3, 0, [42, 42, 47]) )
TESTS[1].append( (3, 0, [47, 42, 42]) )

TESTS[2] = [ (x, 1000, y) for (x, _, y) in TESTS[1] ]

for batch in [1,2,3,4,5]:
    lo, hi = int(0.1*MAXN[batch]), int(0.9*MAXN[batch])
    TESTS[batch].append( (randint(lo,hi), ONLYL[batch], gen_few(MAXN[batch],2)) )
    TESTS[batch].append( (randint(lo,hi), ONLYL[batch], gen_few(MAXN[batch],3)) )
    TESTS[batch].append( (1, ONLYL[batch], gen_few(MAXN[batch],3)) )
    TESTS[batch].append( (MAXN[batch], ONLYL[batch], gen_few(MAXN[batch],3)) )
    for K in [1, 2, randint(3,MAXN[batch]-2), randint(3,MAXN[batch]-2), randint(3,MAXN[batch]-2), MAXN[batch]-1, MAXN[batch] ]:
        A, K = gen_solvable( MAXN[batch], K )
        TESTS[batch].append( (K, ONLYL[batch], A) )
    K = MAXN[batch]//3
    TESTS[batch].append( (K, ONLYL[batch], gen_reverse(MAXN[batch],K)) )
    TESTS[batch].append( (K, ONLYL[batch], gen_reverse(MAXN[batch],K,10)) )

for batch in [4,5]:
    for t in range(10):
        N = MAXN[batch]
        K = randint(2,N-1)
        A, K = gen_solvable(N,K)
        TESTS[batch].append( (K, ONLYL[batch], A) )


for batch in range(1,6):
    for i, test in enumerate(TESTS[batch]):
        K, L, data = test
        N = len(data)
        assert 1 <= N <= MAXN[batch]
        assert 1 <= K <= N
        assert L == ONLYL[batch]
        assert 1 <= min(data) and max(data) <= 10**9

        save(f'{batch:02d}{abc[i]}.in', *test)
